# Criteo API SDK for Python

## Introduction
API Client Libraries can facilitate your use of the Criteo API allowing you to build unique and customized solutions to serve your businesses and clients.
These libraries can reduce the amount of code you need to write in order to start accessing Criteo programmatically. They also can help expedite troubleshooting, should you encounter any issues.

More information on how to use Criteo API and these SDKs can be found at: [https://developers.criteo.com/](https://developers.criteo.com/).

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- Package version: 0.0.250218

## Requirements

Python 2.7 and 3.5+

## Installation & Usage
### pip install

```sh
pip install criteo-api-retailmedia-sdk==0.0.250218
```
(you may need to run `pip` with root permission: `sudo pip install criteo-api-retailmedia-sdk==0.0.250218`)

Then import the package:
```python
import criteo_api_retailmedia_preview
```

### Manual Installation using [Setuptools](http://pypi.python.org/pypi/setuptools)

Download the code or clone the repository locally, then execute the following command:

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import criteo_api_retailmedia_preview
```

## Example
There are multiple examples for the different OAuth flows that the SDK supports.
- See [test/example_application_with_client_credentials.py](test/example_application_with_client_credentials.py) for an example with Client Credentials.
- See [test/example_application_with_auth_code.py](test/example_application_with_auth_code.py) for an example with Authorization Code.
Once you follow the authorization code flow, you will have a refresh token that has to be used to regenerate access token for future usage. 
    - See [test/example_application_with_refresh_token.py](test/example_application_with_refresh_token.py) for an example with Refresh Token .

## Documentation for API Endpoints

The developers documentation is available at: *https://developers.criteo.com*.

All URIs are relative to *https://api.criteo.com*.

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountsApi* | [**get_api_external_v1_account_private_market_child_accounts_by_account_id**](docs/AccountsApi.md#get_api_external_v1_account_private_market_child_accounts_by_account_id) | **GET** /preview/retail-media/account-management/accounts/{accountId}/private-market-child-accounts | 
*AccountsApi* | [**grant_consent**](docs/AccountsApi.md#grant_consent) | **POST** /preview/retail-media/accounts/{accountId}/grant-consent | 
*AccountsApi* | [**search_sellers**](docs/AccountsApi.md#search_sellers) | **POST** /preview/retail-media/accounts/sellers/search | 
*AnalyticsApi* | [**generate_async_accounts_report**](docs/AnalyticsApi.md#generate_async_accounts_report) | **POST** /preview/retail-media/reports/accounts | 
*AnalyticsApi* | [**generate_async_campaigns_report**](docs/AnalyticsApi.md#generate_async_campaigns_report) | **POST** /preview/retail-media/reports/campaigns | 
*AnalyticsApi* | [**generate_async_fill_rate_report**](docs/AnalyticsApi.md#generate_async_fill_rate_report) | **POST** /preview/retail-media/reports/fillrate | 
*AnalyticsApi* | [**generate_async_line_items_report**](docs/AnalyticsApi.md#generate_async_line_items_report) | **POST** /preview/retail-media/reports/line-items | 
*AnalyticsApi* | [**generate_sync_attributed_transactions_report**](docs/AnalyticsApi.md#generate_sync_attributed_transactions_report) | **POST** /preview/retail-media/reports/sync/attributed-transactions | 
*AnalyticsApi* | [**generate_sync_campaigns_report**](docs/AnalyticsApi.md#generate_sync_campaigns_report) | **POST** /preview/retail-media/reports/sync/campaigns | 
*AnalyticsApi* | [**generate_sync_line_items_report**](docs/AnalyticsApi.md#generate_sync_line_items_report) | **POST** /preview/retail-media/reports/sync/line-items | 
*AnalyticsApi* | [**get_async_export_output**](docs/AnalyticsApi.md#get_async_export_output) | **GET** /preview/retail-media/reports/{reportId}/output | 
*AnalyticsApi* | [**get_async_export_status**](docs/AnalyticsApi.md#get_async_export_status) | **GET** /preview/retail-media/reports/{reportId}/status | 
*AudienceApi* | [**bulk_create_audience_segments**](docs/AudienceApi.md#bulk_create_audience_segments) | **POST** /preview/retail-media/accounts/{account-id}/audience-segments/create | 
*AudienceApi* | [**bulk_delete_audience_segments**](docs/AudienceApi.md#bulk_delete_audience_segments) | **POST** /preview/retail-media/accounts/{account-id}/audience-segments/delete | 
*AudienceApi* | [**bulk_update_audience_segments**](docs/AudienceApi.md#bulk_update_audience_segments) | **PATCH** /preview/retail-media/accounts/{account-id}/audience-segments | 
*AudienceApi* | [**delete_contact_list_identifiers**](docs/AudienceApi.md#delete_contact_list_identifiers) | **POST** /preview/retail-media/audience-segments/{audience-segment-id}/contact-list/clear | 
*AudienceApi* | [**get_audience_segment_contact_list_statistics**](docs/AudienceApi.md#get_audience_segment_contact_list_statistics) | **GET** /preview/retail-media/accounts/{account-id}/audience-segments/{audience-segment-id}/contact-list | 
*AudienceApi* | [**search_audience_segments**](docs/AudienceApi.md#search_audience_segments) | **POST** /preview/retail-media/accounts/{account-id}/audience-segments/search | 
*AudienceApi* | [**search_audiences**](docs/AudienceApi.md#search_audiences) | **POST** /preview/retail-media/accounts/{account-id}/audiences/search | 
*AudienceApi* | [**update_contact_list_identifiers**](docs/AudienceApi.md#update_contact_list_identifiers) | **POST** /preview/retail-media/audience-segments/{audience-segment-id}/contact-list/add-remove | 
*BalanceApi* | [**get_api_v2_external_account_balances_by_account_id**](docs/BalanceApi.md#get_api_v2_external_account_balances_by_account_id) | **GET** /preview/retail-media/accounts/{account-id}/balances | 
*BalanceApi* | [**get_api_v2_external_account_by_account_id_balancesbalance_id**](docs/BalanceApi.md#get_api_v2_external_account_by_account_id_balancesbalance_id) | **GET** /preview/retail-media/accounts/{account-id}/balances/{balance-id} | 
*BalanceApi* | [**get_balance_history**](docs/BalanceApi.md#get_balance_history) | **GET** /preview/retail-media/balances/{balanceId}/history | 
*BalanceApi* | [**patch_api_v2_external_account_by_account_id_balancesbalance_id**](docs/BalanceApi.md#patch_api_v2_external_account_by_account_id_balancesbalance_id) | **PATCH** /preview/retail-media/accounts/{account-id}/balances/{balance-id} | 
*BalanceApi* | [**post_api_v2_external_account_balances_by_account_id**](docs/BalanceApi.md#post_api_v2_external_account_balances_by_account_id) | **POST** /preview/retail-media/accounts/{account-id}/balances | 
*BalanceApi* | [**post_api_v2_external_account_change_dates_by_account_id_balancesbalance_id**](docs/BalanceApi.md#post_api_v2_external_account_change_dates_by_account_id_balancesbalance_id) | **POST** /preview/retail-media/accounts/{account-id}/balances/{balance-id}/change-dates | 
*CampaignApi* | [**add_remove_keywords**](docs/CampaignApi.md#add_remove_keywords) | **POST** /preview/retail-media/line-items/{id}/keywords/add-remove | 
*CampaignApi* | [**append_promoted_products**](docs/CampaignApi.md#append_promoted_products) | **POST** /preview/retail-media/line-items/{line-item-id}/products/append | 
*CampaignApi* | [**delete_api202210_external_line_item_product_buttons_by_line_item_id_product_button_id**](docs/CampaignApi.md#delete_api202210_external_line_item_product_buttons_by_line_item_id_product_button_id) | **DELETE** /preview/retail-media/line-items/{line-item-id}/product-buttons/{product-button-id} | 
*CampaignApi* | [**delete_promoted_products**](docs/CampaignApi.md#delete_promoted_products) | **POST** /preview/retail-media/line-items/{line-item-id}/products/delete | 
*CampaignApi* | [**fetch_keywords**](docs/CampaignApi.md#fetch_keywords) | **GET** /preview/retail-media/line-items/{id}/keywords | 
*CampaignApi* | [**fetch_promoted_products**](docs/CampaignApi.md#fetch_promoted_products) | **GET** /preview/retail-media/line-items/{line-item-id}/products | 
*CampaignApi* | [**get_api202210_external_line_item_product_buttons_by_line_item_id**](docs/CampaignApi.md#get_api202210_external_line_item_product_buttons_by_line_item_id) | **GET** /preview/retail-media/line-items/{line-item-id}/product-buttons | 
*CampaignApi* | [**get_api202210_external_line_item_product_buttons_by_line_item_id_product_button_id**](docs/CampaignApi.md#get_api202210_external_line_item_product_buttons_by_line_item_id_product_button_id) | **GET** /preview/retail-media/line-items/{line-item-id}/product-buttons/{product-button-id} | 
*CampaignApi* | [**get_api_v1_external_retailer_brands_by_retailer_id**](docs/CampaignApi.md#get_api_v1_external_retailer_brands_by_retailer_id) | **GET** /preview/retail-media/retailers/{retailerId}/brands | 
*CampaignApi* | [**get_api_v1_external_retailer_by_retailer_id_seller_by_seller**](docs/CampaignApi.md#get_api_v1_external_retailer_by_retailer_id_seller_by_seller) | **GET** /preview/retail-media/retailers/{retailerId}/sellers/{seller} | 
*CampaignApi* | [**get_api_v1_external_retailer_category_cpc_rates_by_retailer_id**](docs/CampaignApi.md#get_api_v1_external_retailer_category_cpc_rates_by_retailer_id) | **GET** /preview/retail-media/retailers/{retailer-id}/cpc-rates | 
*CampaignApi* | [**get_api_v1_external_retailer_placements_by_retailer_id**](docs/CampaignApi.md#get_api_v1_external_retailer_placements_by_retailer_id) | **GET** /preview/retail-media/retailers/{retailer-id}/placements | 
*CampaignApi* | [**get_api_v2_external_account_by_account_id_creativescreative_id**](docs/CampaignApi.md#get_api_v2_external_account_by_account_id_creativescreative_id) | **GET** /preview/retail-media/accounts/{account-id}/creatives/{creative-id} | 
*CampaignApi* | [**get_api_v2_external_campaign_preferred_line_items_by_campaign_id**](docs/CampaignApi.md#get_api_v2_external_campaign_preferred_line_items_by_campaign_id) | **GET** /preview/retail-media/campaigns/{campaign-id}/preferred-line-items | 
*CampaignApi* | [**get_api_v2_external_line_item_bid_multipliers_by_line_item_id**](docs/CampaignApi.md#get_api_v2_external_line_item_bid_multipliers_by_line_item_id) | **GET** /preview/retail-media/line-items/{line-item-id}/bid-multipliers | 
*CampaignApi* | [**get_api_v2_external_preferred_line_item_by_line_item_id**](docs/CampaignApi.md#get_api_v2_external_preferred_line_item_by_line_item_id) | **GET** /preview/retail-media/preferred-line-items/{line-item-id} | 
*CampaignApi* | [**get_cpc_min_bids_by_sku_ids_v1**](docs/CampaignApi.md#get_cpc_min_bids_by_sku_ids_v1) | **POST** /preview/retail-media/retailers/{retailerId}/cpc-min-bids | 
*CampaignApi* | [**get_recommended_keywords**](docs/CampaignApi.md#get_recommended_keywords) | **GET** /preview/retail-media/line-items/{externalLineItemId}/keywords/recommended | 
*CampaignApi* | [**pause_promoted_products**](docs/CampaignApi.md#pause_promoted_products) | **POST** /preview/retail-media/line-items/{line-item-id}/products/pause | 
*CampaignApi* | [**post_api202110_external_campaign_preferred_line_items_by_campaign_id**](docs/CampaignApi.md#post_api202110_external_campaign_preferred_line_items_by_campaign_id) | **POST** /preview/retail-media/campaigns/{campaign-id}/preferred-line-items | 
*CampaignApi* | [**post_api202210_external_line_item_product_buttons_create_by_line_item_id**](docs/CampaignApi.md#post_api202210_external_line_item_product_buttons_create_by_line_item_id) | **POST** /preview/retail-media/line-items/{line-item-id}/product-buttons/create | 
*CampaignApi* | [**post_api_v1_external_account_catalogs_sellers_by_account_id**](docs/CampaignApi.md#post_api_v1_external_account_catalogs_sellers_by_account_id) | **POST** /preview/retail-media/accounts/{accountId}/catalogs/sellers | 
*CampaignApi* | [**post_api_v1_external_catalogs_sku_retrieval**](docs/CampaignApi.md#post_api_v1_external_catalogs_sku_retrieval) | **POST** /preview/retail-media/catalogs/sku-retrieval | 
*CampaignApi* | [**post_api_v1_external_catalogs_sku_search**](docs/CampaignApi.md#post_api_v1_external_catalogs_sku_search) | **POST** /preview/retail-media/catalogs/sku-search | 
*CampaignApi* | [**post_api_v1_external_catalogs_sku_search_account_id_and_retailer_id**](docs/CampaignApi.md#post_api_v1_external_catalogs_sku_search_account_id_and_retailer_id) | **POST** /preview/retail-media/catalogs/sku-search/accounts/{account-id}/retailers/{retailer-id} | 
*CampaignApi* | [**post_api_v1_external_catalogs_sku_search_retailer_by_retailer_id**](docs/CampaignApi.md#post_api_v1_external_catalogs_sku_search_retailer_by_retailer_id) | **POST** /preview/retail-media/catalogs/sku/search/retailers/{retailer-id} | 
*CampaignApi* | [**post_api_v2_external_account_creatives_by_account_id**](docs/CampaignApi.md#post_api_v2_external_account_creatives_by_account_id) | **POST** /preview/retail-media/accounts/{account-id}/creatives | 
*CampaignApi* | [**post_api_v2_external_account_creatives_search_by_account_id**](docs/CampaignApi.md#post_api_v2_external_account_creatives_search_by_account_id) | **POST** /preview/retail-media/accounts/{account-id}/creatives/search | 
*CampaignApi* | [**put_api202110_external_preferred_line_item_by_line_item_id**](docs/CampaignApi.md#put_api202110_external_preferred_line_item_by_line_item_id) | **PUT** /preview/retail-media/preferred-line-items/{line-item-id} | 
*CampaignApi* | [**put_api202210_external_line_item_product_buttons_by_line_item_id_product_button_id**](docs/CampaignApi.md#put_api202210_external_line_item_product_buttons_by_line_item_id_product_button_id) | **PUT** /preview/retail-media/line-items/{line-item-id}/product-buttons/{product-button-id} | 
*CampaignApi* | [**put_api_v2_external_account_by_account_id_creativescreative_id**](docs/CampaignApi.md#put_api_v2_external_account_by_account_id_creativescreative_id) | **PUT** /preview/retail-media/accounts/{account-id}/creatives/{creative-id} | 
*CampaignApi* | [**put_api_v2_external_line_item_bid_multipliers_by_line_item_id**](docs/CampaignApi.md#put_api_v2_external_line_item_bid_multipliers_by_line_item_id) | **PUT** /preview/retail-media/line-items/{line-item-id}/bid-multipliers | 
*CampaignApi* | [**search_brands_by_name_async_v1**](docs/CampaignApi.md#search_brands_by_name_async_v1) | **POST** /preview/retail-media/brands/search | 
*CampaignApi* | [**set_keyword_bids**](docs/CampaignApi.md#set_keyword_bids) | **POST** /preview/retail-media/line-items/{id}/keywords/set-bid | 
*CampaignApi* | [**unpause_promoted_products**](docs/CampaignApi.md#unpause_promoted_products) | **POST** /preview/retail-media/line-items/{line-item-id}/products/unpause | 
*CatalogApi* | [**preview_retail_media_catalog_products_batch_post**](docs/CatalogApi.md#preview_retail_media_catalog_products_batch_post) | **POST** /preview/retail-media/catalog/products/batch | 
*CatalogApi* | [**preview_retail_media_catalog_products_batch_report_operation_token_get**](docs/CatalogApi.md#preview_retail_media_catalog_products_batch_report_operation_token_get) | **GET** /preview/retail-media/catalog/products/batch/report/{operation-token} | 
*GatewayApi* | [**get_current_application**](docs/GatewayApi.md#get_current_application) | **GET** /preview/retail-media/me | 
*OnSiteRecommendationApi* | [**chatbot_product_recommendations**](docs/OnSiteRecommendationApi.md#chatbot_product_recommendations) | **POST** /preview/retail-media/chatbot-catalogs/{catalogid}/product-recommendations | 


## Documentation For Models

 - [AddRemoveKeywordModel](docs/AddRemoveKeywordModel.md)
 - [AddRemoveKeywordsModel](docs/AddRemoveKeywordsModel.md)
 - [AddRemoveKeywordsModelRequest](docs/AddRemoveKeywordsModelRequest.md)
 - [AddRemoveKeywordsModelResource](docs/AddRemoveKeywordsModelResource.md)
 - [ApplicationSummaryModel](docs/ApplicationSummaryModel.md)
 - [ApplicationSummaryModelResource](docs/ApplicationSummaryModelResource.md)
 - [ApplicationSummaryModelResponse](docs/ApplicationSummaryModelResponse.md)
 - [AsyncAccountsReport](docs/AsyncAccountsReport.md)
 - [AsyncAccountsReportRequest](docs/AsyncAccountsReportRequest.md)
 - [AsyncAccountsReportResource](docs/AsyncAccountsReportResource.md)
 - [AsyncCampaignsReport](docs/AsyncCampaignsReport.md)
 - [AsyncCampaignsReportRequest](docs/AsyncCampaignsReportRequest.md)
 - [AsyncCampaignsReportResource](docs/AsyncCampaignsReportResource.md)
 - [AsyncFillRateReport](docs/AsyncFillRateReport.md)
 - [AsyncFillRateReportRequest](docs/AsyncFillRateReportRequest.md)
 - [AsyncFillRateReportResource](docs/AsyncFillRateReportResource.md)
 - [AsyncLineItemsReport](docs/AsyncLineItemsReport.md)
 - [AsyncLineItemsReportRequest](docs/AsyncLineItemsReportRequest.md)
 - [AsyncLineItemsReportResource](docs/AsyncLineItemsReportResource.md)
 - [AsyncReportResponse](docs/AsyncReportResponse.md)
 - [AudienceError](docs/AudienceError.md)
 - [AudienceWarning](docs/AudienceWarning.md)
 - [BalanceHistoryChangeDataCaptureV1](docs/BalanceHistoryChangeDataCaptureV1.md)
 - [BalanceResponseV2](docs/BalanceResponseV2.md)
 - [BalanceResponseV2Response](docs/BalanceResponseV2Response.md)
 - [BatchAcceptedResponse](docs/BatchAcceptedResponse.md)
 - [BotMessage](docs/BotMessage.md)
 - [Brand](docs/Brand.md)
 - [BrandIdSearchRequest](docs/BrandIdSearchRequest.md)
 - [BrandIdSearchResult](docs/BrandIdSearchResult.md)
 - [BrandPreview](docs/BrandPreview.md)
 - [BrandPreviewListResponse](docs/BrandPreviewListResponse.md)
 - [Category](docs/Category.md)
 - [Category202204](docs/Category202204.md)
 - [ChangeDatesOfBalanceV2](docs/ChangeDatesOfBalanceV2.md)
 - [ChangeDatesOfBalanceV2Request](docs/ChangeDatesOfBalanceV2Request.md)
 - [ChangeDetailsV1](docs/ChangeDetailsV1.md)
 - [ChoiceVariableValue](docs/ChoiceVariableValue.md)
 - [ColorVariableValue](docs/ColorVariableValue.md)
 - [CommonError](docs/CommonError.md)
 - [CommonProblem](docs/CommonProblem.md)
 - [CommonWarning](docs/CommonWarning.md)
 - [CpcMinBidsRequest](docs/CpcMinBidsRequest.md)
 - [CpcMinBidsResponse](docs/CpcMinBidsResponse.md)
 - [CpcRateCardPreview](docs/CpcRateCardPreview.md)
 - [CpcRateCardPreviewResponse](docs/CpcRateCardPreviewResponse.md)
 - [CreateBalanceV2](docs/CreateBalanceV2.md)
 - [CreateBalanceV2Request](docs/CreateBalanceV2Request.md)
 - [Creative2](docs/Creative2.md)
 - [Creative2ListResponse](docs/Creative2ListResponse.md)
 - [Creative2Response](docs/Creative2Response.md)
 - [CreativeCreateModel2](docs/CreativeCreateModel2.md)
 - [CreativeUpdateModel2](docs/CreativeUpdateModel2.md)
 - [CustomAttribute](docs/CustomAttribute.md)
 - [EntityResourceBrandIdSearchResult](docs/EntityResourceBrandIdSearchResult.md)
 - [EntityResourceCollectionOutcomeBrandIdSearchResultPagingOffsetLimitMetadata](docs/EntityResourceCollectionOutcomeBrandIdSearchResultPagingOffsetLimitMetadata.md)
 - [EntityResourceCollectionOutcomeOfRetailMediaChildAccount](docs/EntityResourceCollectionOutcomeOfRetailMediaChildAccount.md)
 - [EntityResourceOfRetailMediaChildAccount](docs/EntityResourceOfRetailMediaChildAccount.md)
 - [ErrorCodeResponse](docs/ErrorCodeResponse.md)
 - [ExportReportColumn](docs/ExportReportColumn.md)
 - [ExportReportMetaData](docs/ExportReportMetaData.md)
 - [ExternalCatalogStatus](docs/ExternalCatalogStatus.md)
 - [ExternalLineItemBidMultipliersV2](docs/ExternalLineItemBidMultipliersV2.md)
 - [ExternalLineItemCappingV2](docs/ExternalLineItemCappingV2.md)
 - [ExternalLineItemPageCategoryV2](docs/ExternalLineItemPageCategoryV2.md)
 - [ExternalLineItemPageV2](docs/ExternalLineItemPageV2.md)
 - [ExternalPreferredLineItemCreateModelV2](docs/ExternalPreferredLineItemCreateModelV2.md)
 - [ExternalPreferredLineItemUpdateModelV2](docs/ExternalPreferredLineItemUpdateModelV2.md)
 - [ExternalPreferredLineItemV2](docs/ExternalPreferredLineItemV2.md)
 - [ExternalProductButtonRequest](docs/ExternalProductButtonRequest.md)
 - [ExternalProductButtonResponse](docs/ExternalProductButtonResponse.md)
 - [ExternalRetailMediaChildAccount](docs/ExternalRetailMediaChildAccount.md)
 - [FailResponse](docs/FailResponse.md)
 - [FilesVariableValue](docs/FilesVariableValue.md)
 - [GrantConsentInput](docs/GrantConsentInput.md)
 - [GrantConsentModel](docs/GrantConsentModel.md)
 - [GrantConsentModelValueResource](docs/GrantConsentModelValueResource.md)
 - [HyperlinkVariableValue](docs/HyperlinkVariableValue.md)
 - [InbotDiscussion](docs/InbotDiscussion.md)
 - [InbotDiscussionBodyModel](docs/InbotDiscussionBodyModel.md)
 - [InbotDiscussionDataInstanceModel](docs/InbotDiscussionDataInstanceModel.md)
 - [InputKeywords](docs/InputKeywords.md)
 - [InputKeywordsModel](docs/InputKeywordsModel.md)
 - [InputResourceOfPreferredLineItemCreateModelV2](docs/InputResourceOfPreferredLineItemCreateModelV2.md)
 - [Installment](docs/Installment.md)
 - [JsonApiBodyWithIdOfInt64AndCatalogStatusAndCatalogStatus](docs/JsonApiBodyWithIdOfInt64AndCatalogStatusAndCatalogStatus.md)
 - [JsonApiBodyWithIdOfInt64AndLineItemBidMultipliersV2AndLineItemBidMultipliersV2](docs/JsonApiBodyWithIdOfInt64AndLineItemBidMultipliersV2AndLineItemBidMultipliersV2.md)
 - [JsonApiBodyWithoutIdOfSellerCatalogRequestAndSellerCatalogRequest](docs/JsonApiBodyWithoutIdOfSellerCatalogRequestAndSellerCatalogRequest.md)
 - [JsonApiRequestOfSellerCatalogRequest](docs/JsonApiRequestOfSellerCatalogRequest.md)
 - [JsonApiSingleResponseOfCatalogStatus](docs/JsonApiSingleResponseOfCatalogStatus.md)
 - [JsonApiSingleResponseOfLineItemBidMultipliersV2](docs/JsonApiSingleResponseOfLineItemBidMultipliersV2.md)
 - [KeywordDataModel](docs/KeywordDataModel.md)
 - [Keywords](docs/Keywords.md)
 - [KeywordsModel](docs/KeywordsModel.md)
 - [KeywordsModelResource](docs/KeywordsModelResource.md)
 - [KeywordsModelResponse](docs/KeywordsModelResponse.md)
 - [LineItemBidMultipliersV2Request](docs/LineItemBidMultipliersV2Request.md)
 - [LineItemBidMultipliersV2Response](docs/LineItemBidMultipliersV2Response.md)
 - [LineItemProductStatus](docs/LineItemProductStatus.md)
 - [LoyaltyPoints](docs/LoyaltyPoints.md)
 - [MatchTypeModel](docs/MatchTypeModel.md)
 - [Message](docs/Message.md)
 - [MessageBodyModel](docs/MessageBodyModel.md)
 - [MessageDataInstanceModel](docs/MessageDataInstanceModel.md)
 - [MessageError](docs/MessageError.md)
 - [Metadata](docs/Metadata.md)
 - [NillableString](docs/NillableString.md)
 - [OffsetPageMetadata](docs/OffsetPageMetadata.md)
 - [Outcome](docs/Outcome.md)
 - [PageMetadata](docs/PageMetadata.md)
 - [PageOfBalanceHistoryChangeDataCaptureV1](docs/PageOfBalanceHistoryChangeDataCaptureV1.md)
 - [PageTypeEnvironment2](docs/PageTypeEnvironment2.md)
 - [PagedResourceCollectionOutcomeOfBalanceResponseV2](docs/PagedResourceCollectionOutcomeOfBalanceResponseV2.md)
 - [PagingOffsetLimitMetadata](docs/PagingOffsetLimitMetadata.md)
 - [PlacementPreview](docs/PlacementPreview.md)
 - [PlacementPreviewListResponse](docs/PlacementPreviewListResponse.md)
 - [PreferredLineItemCreateModelV2Request](docs/PreferredLineItemCreateModelV2Request.md)
 - [PreferredLineItemUpdateModelV2Request](docs/PreferredLineItemUpdateModelV2Request.md)
 - [PreferredLineItemV2PagedListResponse](docs/PreferredLineItemV2PagedListResponse.md)
 - [PreferredLineItemV2Response](docs/PreferredLineItemV2Response.md)
 - [Price](docs/Price.md)
 - [ProblemDetails](docs/ProblemDetails.md)
 - [Product](docs/Product.md)
 - [ProductButtonListRequest](docs/ProductButtonListRequest.md)
 - [ProductButtonListResponse](docs/ProductButtonListResponse.md)
 - [ProductButtonRequest](docs/ProductButtonRequest.md)
 - [ProductImporterError](docs/ProductImporterError.md)
 - [ProductImporterWarning](docs/ProductImporterWarning.md)
 - [ProductMetadata](docs/ProductMetadata.md)
 - [ProductRecommendation](docs/ProductRecommendation.md)
 - [ProductResourceOutcome](docs/ProductResourceOutcome.md)
 - [ProductShipping](docs/ProductShipping.md)
 - [ProductShippingDimension](docs/ProductShippingDimension.md)
 - [ProductShippingWeight](docs/ProductShippingWeight.md)
 - [ProductTax](docs/ProductTax.md)
 - [ProductUnitPricingBaseMeasure](docs/ProductUnitPricingBaseMeasure.md)
 - [ProductUnitPricingMeasure](docs/ProductUnitPricingMeasure.md)
 - [ProductsCustomBatchRequest](docs/ProductsCustomBatchRequest.md)
 - [ProductsCustomBatchRequestEntry](docs/ProductsCustomBatchRequestEntry.md)
 - [PromotedProduct](docs/PromotedProduct.md)
 - [PromotedProductResource](docs/PromotedProductResource.md)
 - [PromotedProductResourceCollectionInput](docs/PromotedProductResourceCollectionInput.md)
 - [PromotedProductResourceCollectionOutcome](docs/PromotedProductResourceCollectionOutcome.md)
 - [RecommendedKeywordsResult](docs/RecommendedKeywordsResult.md)
 - [ReportDataResponseResource](docs/ReportDataResponseResource.md)
 - [ReportDetailError](docs/ReportDetailError.md)
 - [ReportDetailErrors](docs/ReportDetailErrors.md)
 - [ReportDetailWarning](docs/ReportDetailWarning.md)
 - [ReportDetailWarnings](docs/ReportDetailWarnings.md)
 - [ReportOkResponse](docs/ReportOkResponse.md)
 - [ReportOutcome](docs/ReportOutcome.md)
 - [ReportResponse](docs/ReportResponse.md)
 - [ResourceOfBalanceResponseV2](docs/ResourceOfBalanceResponseV2.md)
 - [ResourceOfBrandPreview](docs/ResourceOfBrandPreview.md)
 - [ResourceOfChangeDatesOfBalanceV2](docs/ResourceOfChangeDatesOfBalanceV2.md)
 - [ResourceOfCpcRateCardPreview](docs/ResourceOfCpcRateCardPreview.md)
 - [ResourceOfCreateBalanceV2](docs/ResourceOfCreateBalanceV2.md)
 - [ResourceOfCreative2](docs/ResourceOfCreative2.md)
 - [ResourceOfLineItemBidMultipliersV2](docs/ResourceOfLineItemBidMultipliersV2.md)
 - [ResourceOfPlacementPreview](docs/ResourceOfPlacementPreview.md)
 - [ResourceOfPreferredLineItemUpdateModelV2](docs/ResourceOfPreferredLineItemUpdateModelV2.md)
 - [ResourceOfPreferredLineItemV2](docs/ResourceOfPreferredLineItemV2.md)
 - [ResourceOfProductButtonRequest](docs/ResourceOfProductButtonRequest.md)
 - [ResourceOfProductButtonResponse](docs/ResourceOfProductButtonResponse.md)
 - [ResourceOfSellerPreview](docs/ResourceOfSellerPreview.md)
 - [ResourceOfSkuDataPreview](docs/ResourceOfSkuDataPreview.md)
 - [ResourceOfSkuSearchRequestPreview](docs/ResourceOfSkuSearchRequestPreview.md)
 - [ResourceOfSkuSearchRequestSlimPreview](docs/ResourceOfSkuSearchRequestSlimPreview.md)
 - [ResourceOfSkuSearchRequestSlimV2Preview](docs/ResourceOfSkuSearchRequestSlimV2Preview.md)
 - [ResourceOfSkuSlimDataPreview](docs/ResourceOfSkuSlimDataPreview.md)
 - [ResourceOfSkuSlimDataV2](docs/ResourceOfSkuSlimDataV2.md)
 - [ResourceOfUpdateBalanceModelV2](docs/ResourceOfUpdateBalanceModelV2.md)
 - [ResourceOutcome](docs/ResourceOutcome.md)
 - [RetailMediaContactlistAmendment](docs/RetailMediaContactlistAmendment.md)
 - [RetailMediaContactlistAmendmentAttributes](docs/RetailMediaContactlistAmendmentAttributes.md)
 - [RetailMediaContactlistAmendmentRequest](docs/RetailMediaContactlistAmendmentRequest.md)
 - [RetailMediaContactlistOperation](docs/RetailMediaContactlistOperation.md)
 - [RetailMediaContactlistOperationResponseAttributes](docs/RetailMediaContactlistOperationResponseAttributes.md)
 - [RetailMediaSeller](docs/RetailMediaSeller.md)
 - [ReviewStateModel](docs/ReviewStateModel.md)
 - [RmAlgebraNodeV1](docs/RmAlgebraNodeV1.md)
 - [RmAudienceEntityV1](docs/RmAudienceEntityV1.md)
 - [RmAudienceEntityV1Resource](docs/RmAudienceEntityV1Resource.md)
 - [RmAudienceEntityV1RmAudienceSearchMetadataV1ListResponse](docs/RmAudienceEntityV1RmAudienceSearchMetadataV1ListResponse.md)
 - [RmAudienceSearchEntityV1](docs/RmAudienceSearchEntityV1.md)
 - [RmAudienceSearchEntityV1Resource](docs/RmAudienceSearchEntityV1Resource.md)
 - [RmAudienceSearchInputV1](docs/RmAudienceSearchInputV1.md)
 - [RmAudienceSearchMetadataV1](docs/RmAudienceSearchMetadataV1.md)
 - [RmAudienceSegmentBulkCreateInputV1](docs/RmAudienceSegmentBulkCreateInputV1.md)
 - [RmAudienceSegmentBulkDeleteInputV1](docs/RmAudienceSegmentBulkDeleteInputV1.md)
 - [RmAudienceSegmentBulkUpdateInputV1](docs/RmAudienceSegmentBulkUpdateInputV1.md)
 - [RmAudienceSegmentCreateEntityV1](docs/RmAudienceSegmentCreateEntityV1.md)
 - [RmAudienceSegmentCreateEntityV1Resource](docs/RmAudienceSegmentCreateEntityV1Resource.md)
 - [RmAudienceSegmentDeleteEntityV1Resource](docs/RmAudienceSegmentDeleteEntityV1Resource.md)
 - [RmAudienceSegmentEntityV1](docs/RmAudienceSegmentEntityV1.md)
 - [RmAudienceSegmentEntityV1ListResponse](docs/RmAudienceSegmentEntityV1ListResponse.md)
 - [RmAudienceSegmentEntityV1Resource](docs/RmAudienceSegmentEntityV1Resource.md)
 - [RmAudienceSegmentEntityV1RmAudienceSegmentSearchMetadataV1ListResponse](docs/RmAudienceSegmentEntityV1RmAudienceSegmentSearchMetadataV1ListResponse.md)
 - [RmAudienceSegmentIdEntityV1ListResponse](docs/RmAudienceSegmentIdEntityV1ListResponse.md)
 - [RmAudienceSegmentIdEntityV1Resource](docs/RmAudienceSegmentIdEntityV1Resource.md)
 - [RmAudienceSegmentSearchEntityV1](docs/RmAudienceSegmentSearchEntityV1.md)
 - [RmAudienceSegmentSearchEntityV1Resource](docs/RmAudienceSegmentSearchEntityV1Resource.md)
 - [RmAudienceSegmentSearchInputV1](docs/RmAudienceSegmentSearchInputV1.md)
 - [RmAudienceSegmentSearchMetadataV1](docs/RmAudienceSegmentSearchMetadataV1.md)
 - [RmAudienceSegmentUpdateEntityV1](docs/RmAudienceSegmentUpdateEntityV1.md)
 - [RmAudienceSegmentUpdateEntityV1Resource](docs/RmAudienceSegmentUpdateEntityV1Resource.md)
 - [RmContactListCreateV1](docs/RmContactListCreateV1.md)
 - [RmContactListStatisticsEntityV1](docs/RmContactListStatisticsEntityV1.md)
 - [RmContactListStatisticsEntityV1Resource](docs/RmContactListStatisticsEntityV1Resource.md)
 - [RmContactListStatisticsEntityV1Response](docs/RmContactListStatisticsEntityV1Response.md)
 - [RmContactListV1](docs/RmContactListV1.md)
 - [RmEventsV1](docs/RmEventsV1.md)
 - [RmcaCommonProblem](docs/RmcaCommonProblem.md)
 - [SdkApiRestCommonProblem](docs/SdkApiRestCommonProblem.md)
 - [SellerCatalogRequest](docs/SellerCatalogRequest.md)
 - [SellerIdentifier](docs/SellerIdentifier.md)
 - [SellerPreview](docs/SellerPreview.md)
 - [SellerPreviewResponse](docs/SellerPreviewResponse.md)
 - [SellerSearch](docs/SellerSearch.md)
 - [SellerSearchResult](docs/SellerSearchResult.md)
 - [SetBidModel](docs/SetBidModel.md)
 - [SetBidsModel](docs/SetBidsModel.md)
 - [SetBidsModelRequest](docs/SetBidsModelRequest.md)
 - [SetBidsModelResource](docs/SetBidsModelResource.md)
 - [SkuDataPreview](docs/SkuDataPreview.md)
 - [SkuDataPreviewListResponse](docs/SkuDataPreviewListResponse.md)
 - [SkuMinBid](docs/SkuMinBid.md)
 - [SkuSearchRequestPreview](docs/SkuSearchRequestPreview.md)
 - [SkuSearchRequestPreviewRequest](docs/SkuSearchRequestPreviewRequest.md)
 - [SkuSearchRequestSlimPreview](docs/SkuSearchRequestSlimPreview.md)
 - [SkuSearchRequestSlimPreviewRequest](docs/SkuSearchRequestSlimPreviewRequest.md)
 - [SkuSearchRequestSlimV2Preview](docs/SkuSearchRequestSlimV2Preview.md)
 - [SkuSearchRequestSlimV2PreviewRequest](docs/SkuSearchRequestSlimV2PreviewRequest.md)
 - [SkuSlimDataPreview](docs/SkuSlimDataPreview.md)
 - [SkuSlimDataPreviewListResponse](docs/SkuSlimDataPreviewListResponse.md)
 - [SkuSlimDataV2](docs/SkuSlimDataV2.md)
 - [SkuSlimDataV2ListResponse](docs/SkuSlimDataV2ListResponse.md)
 - [StatusResponse](docs/StatusResponse.md)
 - [StatusResponseResource](docs/StatusResponseResource.md)
 - [SyncAttributedTransactionsReport](docs/SyncAttributedTransactionsReport.md)
 - [SyncAttributedTransactionsReportRequest](docs/SyncAttributedTransactionsReportRequest.md)
 - [SyncAttributedTransactionsReportResource](docs/SyncAttributedTransactionsReportResource.md)
 - [SyncCampaignsReport](docs/SyncCampaignsReport.md)
 - [SyncCampaignsReportRequest](docs/SyncCampaignsReportRequest.md)
 - [SyncCampaignsReportResource](docs/SyncCampaignsReportResource.md)
 - [SyncLineItemsReport](docs/SyncLineItemsReport.md)
 - [SyncLineItemsReportRequest](docs/SyncLineItemsReportRequest.md)
 - [SyncLineItemsReportResource](docs/SyncLineItemsReportResource.md)
 - [TemplateVariableValue](docs/TemplateVariableValue.md)
 - [TextVariableValue](docs/TextVariableValue.md)
 - [UpdateBalanceModelV2](docs/UpdateBalanceModelV2.md)
 - [UpdateBalanceModelV2Request](docs/UpdateBalanceModelV2Request.md)
 - [ValueResourceBrandIdSearchRequest](docs/ValueResourceBrandIdSearchRequest.md)
 - [ValueResourceCollectionOutcomeOfSellerSearchResult](docs/ValueResourceCollectionOutcomeOfSellerSearchResult.md)
 - [ValueResourceCpcMinBidsRequest](docs/ValueResourceCpcMinBidsRequest.md)
 - [ValueResourceCpcMinBidsResponse](docs/ValueResourceCpcMinBidsResponse.md)
 - [ValueResourceInputBrandIdSearchRequest](docs/ValueResourceInputBrandIdSearchRequest.md)
 - [ValueResourceInputCpcMinBidsRequest](docs/ValueResourceInputCpcMinBidsRequest.md)
 - [ValueResourceInputOfSellerSearch](docs/ValueResourceInputOfSellerSearch.md)
 - [ValueResourceOfRecommendedKeywordsResult](docs/ValueResourceOfRecommendedKeywordsResult.md)
 - [ValueResourceOfSellerSearch](docs/ValueResourceOfSellerSearch.md)
 - [ValueResourceOfSellerSearchResult](docs/ValueResourceOfSellerSearchResult.md)
 - [ValueResourceOutcomeCpcMinBidsResponse](docs/ValueResourceOutcomeCpcMinBidsResponse.md)
 - [ValueResourceOutcomeOfRecommendedKeywordsResult](docs/ValueResourceOutcomeOfRecommendedKeywordsResult.md)
 - [VideoVariableValue](docs/VideoVariableValue.md)


## Disclaimer

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.